#!/bin/bash

rootdn="cn=directory manager"
rootpw=Secret12
iterations=100
numusers=3000

# Loop through instance creation, testing, and cleanup to make
# multiple attempts at reproducing the problem.
for i in `seq 1 $iterations`; do
    echo "Beginning iteration $i..."

    # Create DS instance
    echo "Creating DS instance..."
    setup-ds.pl --silent --file=./setup.inf

    # Enable memberOf plug-in
    echo "Enabling memberOf plug-in ..."
    ldapmodify -x -D "$rootdn" -w $rootpw -f ./memberof_config.ldif

    # Restart DS to load the memberOf plug-in
    echo "Restarting dirsrv instance ..."
    service dirsrv restart

    # Add large-group
    echo "Adding test group ..."
    ldapmodify -x -D "$rootdn" -w $rootpw -f ./large_group.ldif

    # Loop through addition of users, adding membership, and dereferencing the group members
    for j in `seq 1 $numusers`; do
    echo "Adding user $j ..."
    ldapmodify -x -D "$rootdn" -w $rootpw << EOF
dn: uid=user$j,dc=example,dc=com
changetype: add
objectclass: posixAccount
objectclass: inetUser
cn: User $j
homeDirectory: /home/user$j
uidNumber: 500
gidNumber: 500
EOF

        echo "Adding user $j to large-group ..."
        ./dshang.pl $j
    done

    echo "Iteration $i complete"

    # Remove DS instance
    echo "Removing DS instance..."
    remove-ds.pl -i slapd-localhost
done

